@@ -4,7 +4,7 @@
  *              to build a moderately scalable and highly available server
  *              based on a cluster of servers, with more flexibility.
  *
- * Version:     $Id: tcp_vs_ctl.c,v 1.10 2003/02/22 04:51:57 wensong Exp $
+ * Version:     $Id: tcp_vs_ctl.c,v 1.13 2003/05/23 06:56:14 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -52,7 +52,7 @@
  * Note that accessing the members of struct tcp_vs_service *svc (such as
  * the destination list) need use svc->lock.
  */
-struct list_head  tcp_vs_svc_list;
+struct list_head tcp_vs_svc_list;
 static int tcp_vs_num_services = 0;
 static DECLARE_MUTEX(__tcp_vs_mutex);
 rwlock_t __tcp_vs_svc_lock = RW_LOCK_UNLOCKED;
@@ -67,7 +67,8 @@ int sysctl_ktcpvs_keepalive_timeout = 30;
 #ifdef CONFIG_TCP_VS_DEBUG
 static int sysctl_ktcpvs_debug_level = 0;
 
-int tcp_vs_get_debug_level(void)
+int
+tcp_vs_get_debug_level(void)
 {
 	return sysctl_ktcpvs_debug_level;
 }
@@ -76,17 +77,18 @@ int tcp_vs_get_debug_level(void)
 
 int tcp_vs_sysctl_register(struct tcp_vs_service *svc);
 int tcp_vs_sysctl_unregister(struct tcp_vs_service *svc);
-struct proc_dir_entry *proc_net_ktcpvs_vs_create(struct tcp_vs_service *svc);
+struct proc_dir_entry *proc_net_ktcpvs_vs_create(struct tcp_vs_service
+						 *svc);
 void proc_net_ktcpvs_vs_release(struct tcp_vs_service *svc);
 
 
 /*
  *  Lookup destination by {addr,port} in the given service
  */
-static struct tcp_vs_dest *
+static tcp_vs_dest_t *
 tcp_vs_lookup_dest(struct tcp_vs_service *svc, __u32 daddr, __u16 dport)
 {
-	struct tcp_vs_dest *dest;
+	tcp_vs_dest_t *dest;
 	struct list_head *l, *e;
 
 	read_lock_bh(&svc->lock);
@@ -94,8 +96,8 @@ tcp_vs_lookup_dest(struct tcp_vs_service *svc, __u32 daddr, __u16 dport)
 	 * Find the destination for the given virtual server
 	 */
 	l = &svc->destinations;
-	for (e=l->next; e!=l; e=e->next) {
-		dest = list_entry(e, struct tcp_vs_dest, n_list);
+	for (e = l->next; e != l; e = e->next) {
+		dest = list_entry(e, tcp_vs_dest_t, n_list);
 		if ((dest->addr == daddr) && (dest->port == dport)) {
 			/* HIT */
 			read_unlock_bh(&svc->lock);
@@ -114,7 +116,7 @@ static int
 tcp_vs_add_dest(struct tcp_vs_service *svc,
 		__u32 daddr, __u16 dport, int weight)
 {
-	struct tcp_vs_dest *dest;
+	tcp_vs_dest_t *dest;
 
 	EnterFunction(2);
 
@@ -135,12 +137,12 @@ tcp_vs_add_dest(struct tcp_vs_service *svc,
 	/*
 	 * Allocate and initialize the dest structure
 	 */
-	dest = kmalloc(sizeof(struct tcp_vs_dest), GFP_ATOMIC);
+	dest = kmalloc(sizeof(tcp_vs_dest_t), GFP_ATOMIC);
 	if (dest == NULL) {
 		TCP_VS_ERR("kmalloc failed.\n");
 		return -EFAULT;
 	}
-	memset(dest, 0, sizeof(struct tcp_vs_dest));
+	memset(dest, 0, sizeof(tcp_vs_dest_t));
 
 	dest->addr = daddr;
 	dest->port = dport;
@@ -175,7 +177,7 @@ static int
 tcp_vs_edit_dest(struct tcp_vs_service *svc,
 		 __u32 daddr, __u16 dport, int weight)
 {
-	struct tcp_vs_dest *dest;
+	tcp_vs_dest_t *dest;
 
 	EnterFunction(2);
 
@@ -207,7 +209,7 @@ tcp_vs_edit_dest(struct tcp_vs_service *svc,
  *  Delete a destination from the given virtual server
  */
 static inline void
-__tcp_vs_del_dest(struct tcp_vs_service *svc, struct tcp_vs_dest *dest)
+__tcp_vs_del_dest(struct tcp_vs_service *svc, tcp_vs_dest_t * dest)
 {
 	/*
 	 *  Remove it from the lists.
@@ -228,7 +230,7 @@ __tcp_vs_del_dest(struct tcp_vs_service *svc, struct tcp_vs_dest *dest)
 static int
 tcp_vs_del_dest(struct tcp_vs_service *svc, __u32 daddr, __u16 dport)
 {
-	struct tcp_vs_dest *dest;
+	tcp_vs_dest_t *dest;
 
 	EnterFunction(2);
 
@@ -237,7 +239,8 @@ tcp_vs_del_dest(struct tcp_vs_service *svc, __u32 daddr, __u16 dport)
 	 */
 	dest = tcp_vs_lookup_dest(svc, daddr, dport);
 	if (dest == NULL) {
-		TCP_VS_DBG(0, "tcp_vs_del_dest(): destination not found!\n");
+		TCP_VS_DBG(0,
+			   "tcp_vs_del_dest(): destination not found!\n");
 		return -ENOENT;
 	}
 
@@ -271,7 +274,7 @@ static int
 tcp_vs_add_rule(struct tcp_vs_service *svc,
 		char *pattern, __u32 addr, __u16 port)
 {
-	struct tcp_vs_dest *dest;
+	tcp_vs_dest_t *dest;
 	struct tcp_vs_rule *r;
 	struct list_head *l;
 	int rc = 0;
@@ -300,7 +303,8 @@ tcp_vs_add_rule(struct tcp_vs_service *svc,
 	list_for_each(l, &svc->rule_list) {
 		r = list_entry(l, struct tcp_vs_rule, list);
 		if (!strncmp(pattern, r->pattern, r->len)) {
-			TCP_VS_DBG(2, "add server into an existing rule\n");
+			TCP_VS_DBG(2,
+				   "add server into an existing rule\n");
 			list_add(&dest->r_list, &r->destinations);
 			svc->num_rules++;
 			goto out;
@@ -316,7 +320,7 @@ tcp_vs_add_rule(struct tcp_vs_service *svc,
 	memset(r, 0, sizeof(struct tcp_vs_rule));
 	INIT_LIST_HEAD(&r->destinations);
 
-	if (regcomp(&r->rx, pattern, REG_EXTENDED|REG_NOSUB)) {
+	if (regcomp(&r->rx, pattern, REG_EXTENDED | REG_NOSUB)) {
 		TCP_VS_ERR("pattern compiling failed\n");
 		kfree(r);
 		rc = -EFAULT;
@@ -334,7 +338,7 @@ tcp_vs_add_rule(struct tcp_vs_service *svc,
 		list_add_tail(&r->list, &svc->rule_list);
 	svc->num_rules++;
 
- out:
+      out:
 	write_unlock_bh(&svc->lock);
 	LeaveFunction(2);
 	return rc;
@@ -345,7 +349,7 @@ static int
 tcp_vs_del_rule(struct tcp_vs_service *svc,
 		char *pattern, __u32 addr, __u16 port)
 {
-	struct tcp_vs_dest *dest;
+	tcp_vs_dest_t *dest;
 	struct tcp_vs_rule *r;
 	struct list_head *l, *d;
 
@@ -362,12 +366,10 @@ tcp_vs_del_rule(struct tcp_vs_service *svc,
 	write_unlock_bh(&svc->lock);
 	return -EEXIST;
 
-  hit:
+      hit:
 	list_for_each(d, &r->destinations) {
-		dest = list_entry(d, struct tcp_vs_dest,
-				  r_list);
-		if (dest->addr == addr
-		    && dest->port == port) {
+		dest = list_entry(d, tcp_vs_dest_t, r_list);
+		if (dest->addr == addr && dest->port == port) {
 			TCP_VS_DBG(2, "found the dest\n");
 			svc->num_rules--;
 			list_del_init(&dest->r_list);
@@ -387,21 +389,21 @@ tcp_vs_del_rule(struct tcp_vs_service *svc,
 }
 
 
-static void __tcp_vs_flush_rule(struct tcp_vs_service *svc)
+static void
+__tcp_vs_flush_rule(struct tcp_vs_service *svc)
 {
 	struct list_head *l, *d;
 	struct tcp_vs_rule *r;
-	struct tcp_vs_dest *dest;
+	tcp_vs_dest_t *dest;
 
 	EnterFunction(2);
-	for (l=&svc->rule_list; l->next!=l; ) {
+	for (l = &svc->rule_list; l->next != l;) {
 		r = list_entry(l->next, struct tcp_vs_rule, list);
 		list_del(&r->list);
 		TCP_VS_DBG(2, "flush the rule %s in the service %s\n",
 			   r->pattern, svc->ident.name);
-		for (d=&r->destinations; d->next!=d; ) {
-			dest = list_entry(d->next, struct tcp_vs_dest,
-					  r_list);
+		for (d = &r->destinations; d->next != d;) {
+			dest = list_entry(d->next, tcp_vs_dest_t, r_list);
 			list_del_init(&dest->r_list);
 		}
 		regfree(&r->rx);
@@ -413,12 +415,13 @@ static void __tcp_vs_flush_rule(struct tcp_vs_service *svc)
 
 
 
-struct tcp_vs_service *tcp_vs_lookup_byident(const struct tcp_vs_ident *id)
+struct tcp_vs_service *
+tcp_vs_lookup_byident(const struct tcp_vs_ident *id)
 {
 	struct list_head *e;
 	struct tcp_vs_service *svc;
 
-	list_for_each (e, &tcp_vs_svc_list) {
+	list_for_each(e, &tcp_vs_svc_list) {
 		svc = list_entry(e, struct tcp_vs_service, list);
 		if (!strcmp(id->name, svc->ident.name))
 			/* HIT */
@@ -443,7 +446,7 @@ tcp_vs_add_service(struct tcp_vs_ident *ident, struct tcp_vs_config *conf)
 	if (sched == NULL) {
 		TCP_VS_INFO("Scheduler module tcp_vs_%s.o not found\n",
 			    conf->sched_name);
-		return -EFAULT;
+		return -ENOENT;
 	}
 
 	svc = kmalloc(sizeof(*svc), GFP_ATOMIC);
@@ -472,7 +475,7 @@ tcp_vs_add_service(struct tcp_vs_ident *ident, struct tcp_vs_config *conf)
 	tcp_vs_num_services++;
 	write_unlock_bh(&__tcp_vs_svc_lock);
 
- out:
+      out:
 	tcp_vs_scheduler_put(sched);
 	LeaveFunction(2);
 	return ret;
@@ -490,9 +493,10 @@ tcp_vs_edit_service(struct tcp_vs_service *svc, struct tcp_vs_config *conf)
 	if (strcmp(svc->scheduler->name, conf->sched_name)) {
 		sched = tcp_vs_scheduler_get(conf->sched_name);
 		if (sched == NULL) {
-			TCP_VS_INFO("Scheduler module tcp_vs_%s.o not found\n",
-				    conf->sched_name);
-			return -EFAULT;
+			TCP_VS_INFO
+			    ("Scheduler module tcp_vs_%s.o not found\n",
+			     conf->sched_name);
+			return -ENOENT;
 		}
 		tcp_vs_unbind_scheduler(svc);
 		tcp_vs_bind_scheduler(svc, sched);
@@ -507,10 +511,11 @@ tcp_vs_edit_service(struct tcp_vs_service *svc, struct tcp_vs_config *conf)
 	return 0;
 }
 
-static inline int __tcp_vs_del_service(struct tcp_vs_service *svc)
+static inline int
+__tcp_vs_del_service(struct tcp_vs_service *svc)
 {
 	struct list_head *l;
-	struct tcp_vs_dest *dest;
+	tcp_vs_dest_t *dest;
 
 	if (atomic_read(&svc->running)) {
 		TCP_VS_ERR("The VS is running, you'd better stop it first"
@@ -524,7 +529,7 @@ static inline int __tcp_vs_del_service(struct tcp_vs_service *svc)
 	write_lock_bh(&svc->lock);
 	__tcp_vs_flush_rule(svc);
 	for (l = &svc->destinations; l->next != l;) {
-		dest = list_entry(l->next, struct tcp_vs_dest, n_list);
+		dest = list_entry(l->next, tcp_vs_dest_t, n_list);
 		__tcp_vs_del_dest(svc, dest);
 	}
 	tcp_vs_unbind_scheduler(svc);
@@ -535,7 +540,8 @@ static inline int __tcp_vs_del_service(struct tcp_vs_service *svc)
 	return 0;
 }
 
-static int tcp_vs_del_service(struct tcp_vs_service *svc)
+static int
+tcp_vs_del_service(struct tcp_vs_service *svc)
 {
 	int ret;
 
@@ -550,7 +556,8 @@ static int tcp_vs_del_service(struct tcp_vs_service *svc)
 }
 
 
-int tcp_vs_flush(void)
+int
+tcp_vs_flush(void)
 {
 	struct list_head *l;
 	struct tcp_vs_service *svc;
@@ -559,7 +566,7 @@ int tcp_vs_flush(void)
 	EnterFunction(2);
 
 	write_lock_bh(&__tcp_vs_svc_lock);
-	for (l=&tcp_vs_svc_list; l->next!=l; ) {
+	for (l = &tcp_vs_svc_list; l->next != l;) {
 		svc = list_entry(l->next, struct tcp_vs_service, list);
 		if ((ret = __tcp_vs_del_service(svc)))
 			break;
@@ -570,13 +577,14 @@ int tcp_vs_flush(void)
 	return 0;
 }
 
-static int tcp_vs_start_all(void)
+static int
+tcp_vs_start_all(void)
 {
 	struct list_head *e;
 	struct tcp_vs_service *svc;
 
 	write_lock_bh(&__tcp_vs_svc_lock);
-	list_for_each (e, &tcp_vs_svc_list) {
+	list_for_each(e, &tcp_vs_svc_list) {
 		svc = list_entry(e, struct tcp_vs_service, list);
 		svc->start = 1;
 	}
@@ -585,13 +593,14 @@ static int tcp_vs_start_all(void)
 	return 0;
 }
 
-static int tcp_vs_stop_all(void)
+static int
+tcp_vs_stop_all(void)
 {
 	struct list_head *e;
 	struct tcp_vs_service *svc;
 
 	write_lock_bh(&__tcp_vs_svc_lock);
-	list_for_each (e, &tcp_vs_svc_list) {
+	list_for_each(e, &tcp_vs_svc_list) {
 		svc = list_entry(e, struct tcp_vs_service, list);
 		svc->stop = 1;
 	}
@@ -645,7 +654,7 @@ do_tcp_vs_set_ctl(struct sock *sk, int cmd, void *user, unsigned int len)
 	}
 
 	/* Avoid the non-terminated string here */
-	ident.name[KTCPVS_IDENTNAME_MAXLEN-1] = '\0';
+	ident.name[KTCPVS_IDENTNAME_MAXLEN - 1] = '\0';
 
 	svc = tcp_vs_lookup_byident(&ident);
 	if (!svc && cmd != TCP_VS_SO_SET_ADD) {
@@ -718,8 +727,8 @@ do_tcp_vs_set_ctl(struct sock *sk, int cmd, void *user, unsigned int len)
 		break;
 
 	case TCP_VS_SO_SET_EDITDEST:
-		ret =tcp_vs_edit_dest(svc, dest->addr,
-				      dest->port, dest->weight);
+		ret = tcp_vs_edit_dest(svc, dest->addr,
+				       dest->port, dest->weight);
 		break;
 
 	case TCP_VS_SO_SET_DELDEST:
@@ -748,7 +757,7 @@ do_tcp_vs_set_ctl(struct sock *sk, int cmd, void *user, unsigned int len)
 		ret = -EINVAL;
 	}
 
-  out:
+      out:
 	if (conf)
 		kfree(conf);
 	if (dest)
@@ -765,7 +774,7 @@ static inline int
 __tcp_vs_get_service_entries(const struct tcp_vs_get_services *get,
 			     struct tcp_vs_get_services *uptr)
 {
-	int count=0;
+	int count = 0;
 	struct tcp_vs_service *svc;
 	struct list_head *l;
 	struct tcp_vs_service_u entry;
@@ -773,12 +782,14 @@ __tcp_vs_get_service_entries(const struct tcp_vs_get_services *get,
 
 	if (down_interruptible(&__tcp_vs_mutex))
 		return -ERESTARTSYS;
-	list_for_each (l, &tcp_vs_svc_list) {
+	list_for_each(l, &tcp_vs_svc_list) {
 		if (count >= get->num_services)
 			break;
 		svc = list_entry(l, struct tcp_vs_service, list);
-		memcpy(&entry.ident, &svc->ident, sizeof(struct tcp_vs_ident));
-		memcpy(&entry.conf, &svc->conf, sizeof(struct tcp_vs_config));
+		memcpy(&entry.ident, &svc->ident,
+		       sizeof(struct tcp_vs_ident));
+		memcpy(&entry.conf, &svc->conf,
+		       sizeof(struct tcp_vs_config));
 		entry.num_dests = svc->num_dests;
 		entry.num_rules = svc->num_rules;
 		entry.conns = atomic_read(&svc->conns);
@@ -806,14 +817,14 @@ __tcp_vs_get_dest_entries(const struct tcp_vs_get_dests *get,
 	svc = tcp_vs_lookup_byident(&get->ident);
 	if (svc) {
 		int count = 0;
-		struct tcp_vs_dest *dest;
+		tcp_vs_dest_t *dest;
 		struct list_head *l;
 		struct tcp_vs_dest_u entry;
 
-		list_for_each (l, &svc->destinations) {
+		list_for_each(l, &svc->destinations) {
 			if (count >= get->num_dests)
 				break;
-			dest = list_entry(l, struct tcp_vs_dest, n_list);
+			dest = list_entry(l, tcp_vs_dest_t, n_list);
 			entry.addr = dest->addr;
 			entry.port = dest->port;
 			entry.weight = dest->weight;
@@ -848,17 +859,17 @@ __tcp_vs_get_rule_entries(const struct tcp_vs_get_rules *get,
 		goto out;
 	}
 
-	list_for_each (l, &svc->rule_list) {
+	list_for_each(l, &svc->rule_list) {
 		struct tcp_vs_rule *rule;
 
 		rule = list_entry(l, struct tcp_vs_rule, list);
-		list_for_each (e, &rule->destinations) {
-			struct tcp_vs_dest *dest;
+		list_for_each(e, &rule->destinations) {
+			tcp_vs_dest_t *dest;
 			struct tcp_vs_rule_u entry;
 
 			if (count >= get->num_rules)
 				goto out;
-			dest = list_entry(e, struct tcp_vs_dest, r_list);
+			dest = list_entry(e, tcp_vs_dest_t, r_list);
 			strcpy(entry.pattern, rule->pattern);
 			entry.len = rule->len;
 			entry.addr = dest->addr;
@@ -871,7 +882,7 @@ __tcp_vs_get_rule_entries(const struct tcp_vs_get_rules *get,
 			count++;
 		}
 	}
- out:
+      out:
 	up(&__tcp_vs_mutex);
 	return ret;
 }
@@ -887,119 +898,134 @@ do_tcp_vs_get_ctl(struct sock *sk, int cmd, void *user, int *len)
 
 	switch (cmd) {
 	case TCP_VS_SO_GET_VERSION:
-	{
-		char buf[64];
+		{
+			char buf[64];
 
-		sprintf(buf, "TCP Virtual Server version %d.%d.%d",
-			NVERSION(TCP_VS_VERSION_CODE));
-		if (*len < strlen(buf)+1)
-			return -EINVAL;
-		if (copy_to_user(user, buf, strlen(buf)+1) != 0)
-			return -EFAULT;
-		*len = strlen(buf)+1;
-	}
-	break;
+			sprintf(buf, "TCP Virtual Server version %d.%d.%d",
+				NVERSION(TCP_VS_VERSION_CODE));
+			if (*len < strlen(buf) + 1)
+				return -EINVAL;
+			if (copy_to_user(user, buf, strlen(buf) + 1) != 0)
+				return -EFAULT;
+			*len = strlen(buf) + 1;
+		}
+		break;
 
 	case TCP_VS_SO_GET_INFO:
-	{
-		struct tcp_vs_getinfo info;
-		info.version = TCP_VS_VERSION_CODE;
-		info.num_services = tcp_vs_num_services;
-		if (copy_to_user(user, &info, sizeof(info)) != 0)
-			return -EFAULT;
-	}
-	break;
+		{
+			struct tcp_vs_getinfo info;
+			info.version = TCP_VS_VERSION_CODE;
+			info.num_services = tcp_vs_num_services;
+			if (copy_to_user(user, &info, sizeof(info)) != 0)
+				return -EFAULT;
+		}
+		break;
 
 	case TCP_VS_SO_GET_SERVICES:
-	{
-		struct tcp_vs_get_services get;
+		{
+			struct tcp_vs_get_services get;
 
-		if (*len < sizeof(get)) {
-			TCP_VS_ERR("length: %u < %u\n", *len, sizeof(get));
-			return -EINVAL;
+			if (*len < sizeof(get)) {
+				TCP_VS_ERR("length: %u < %u\n", *len,
+					   sizeof(get));
+				return -EINVAL;
+			}
+			if (copy_from_user(&get, user, sizeof(get)))
+				return -EFAULT;
+			if (*len !=
+			    (sizeof(get) +
+			     sizeof(struct tcp_vs_service_u) *
+			     get.num_services)) {
+				TCP_VS_ERR("length: %u != %u\n", *len,
+					   sizeof(get) +
+					   sizeof(struct tcp_vs_service_u)
+					   * get.num_services);
+				return -EINVAL;
+			}
+			ret = __tcp_vs_get_service_entries(&get, user);
 		}
-		if (copy_from_user(&get, user, sizeof(get)))
-			return -EFAULT;
-		if (*len != (sizeof(get)+sizeof(struct tcp_vs_service_u)*get.num_services)) {
-			TCP_VS_ERR("length: %u != %u\n", *len,
-				   sizeof(get)+sizeof(struct tcp_vs_service_u)*get.num_services);
-			return -EINVAL;
-		}
-		ret = __tcp_vs_get_service_entries(&get, user);
-	}
-	break;
+		break;
 
 	case TCP_VS_SO_GET_SERVICE:
-	{
-		struct tcp_vs_service_u get;
-		struct tcp_vs_service *svc;
+		{
+			struct tcp_vs_service_u get;
+			struct tcp_vs_service *svc;
 
-		if (*len != sizeof(get)) {
-			TCP_VS_ERR("length: %u != %u\n", *len, sizeof(get));
-			return -EINVAL;
+			if (*len != sizeof(get)) {
+				TCP_VS_ERR("length: %u != %u\n", *len,
+					   sizeof(get));
+				return -EINVAL;
+			}
+			if (copy_from_user(&get, user, sizeof(get)))
+				return -EFAULT;
+
+			if (down_interruptible(&__tcp_vs_mutex))
+				return -ERESTARTSYS;
+			svc = tcp_vs_lookup_byident(&get.ident);
+			if (svc) {
+				memcpy(&get.ident, &svc->ident,
+				       sizeof(struct tcp_vs_ident));
+				memcpy(&get.conf, &svc->conf,
+				       sizeof(struct tcp_vs_config));
+				get.num_dests = svc->num_dests;
+				get.num_rules = svc->num_rules;
+				get.conns = atomic_read(&svc->conns);
+				get.running = atomic_read(&svc->running);
+				if (copy_to_user(user, &get, *len) != 0)
+					ret = -EFAULT;
+			} else
+				ret = -ESRCH;
+			up(&__tcp_vs_mutex);
 		}
-		if (copy_from_user(&get, user, sizeof(get)))
-			return -EFAULT;
-
-		if (down_interruptible(&__tcp_vs_mutex))
-			return -ERESTARTSYS;
-		svc = tcp_vs_lookup_byident(&get.ident);
-		if (svc) {
-			memcpy(&get.ident, &svc->ident,
-			       sizeof(struct tcp_vs_ident));
-			memcpy(&get.conf, &svc->conf,
-			       sizeof(struct tcp_vs_config));
-			get.num_dests = svc->num_dests;
-			get.num_rules = svc->num_rules;
-			get.conns = atomic_read(&svc->conns);
-			get.running = atomic_read(&svc->running);
-			if (copy_to_user(user, &get, *len) != 0)
-				ret = -EFAULT;
-		} else
-			ret = -ESRCH;
-		up(&__tcp_vs_mutex);
-	}
-	break;
+		break;
 
 	case TCP_VS_SO_GET_DESTS:
-	{
-		struct tcp_vs_get_dests get;
+		{
+			struct tcp_vs_get_dests get;
 
-		if (*len < sizeof(get)) {
-			TCP_VS_ERR("length: %u < %u\n", *len, sizeof(get));
-			return -EINVAL;
+			if (*len < sizeof(get)) {
+				TCP_VS_ERR("length: %u < %u\n", *len,
+					   sizeof(get));
+				return -EINVAL;
+			}
+			if (copy_from_user(&get, user, sizeof(get)))
+				return -EFAULT;
+			if (*len != (sizeof(get) +
+				     sizeof(struct tcp_vs_dest_u) *
+				     get.num_dests)) {
+				TCP_VS_ERR("length: %u != %u\n", *len,
+					   sizeof(get) +
+					   sizeof(struct tcp_vs_dest_u) *
+					   get.num_dests);
+				return -EINVAL;
+			}
+			ret = __tcp_vs_get_dest_entries(&get, user);
 		}
-		if (copy_from_user(&get, user, sizeof(get)))
-			return -EFAULT;
-		if (*len != (sizeof(get) +
-			     sizeof(struct tcp_vs_dest_u)*get.num_dests)) {
-			TCP_VS_ERR("length: %u != %u\n", *len,
-				   sizeof(get)+sizeof(struct tcp_vs_dest_u)*get.num_dests);
-			return -EINVAL;
-		}
-		ret = __tcp_vs_get_dest_entries(&get, user);
-	}
-	break;
+		break;
 
 	case TCP_VS_SO_GET_RULES:
-	{
-		struct tcp_vs_get_rules get;
+		{
+			struct tcp_vs_get_rules get;
 
-		if (*len < sizeof(get)) {
-			TCP_VS_ERR("length: %u < %u\n", *len, sizeof(get));
-			return -EINVAL;
+			if (*len < sizeof(get)) {
+				TCP_VS_ERR("length: %u < %u\n", *len,
+					   sizeof(get));
+				return -EINVAL;
+			}
+			if (copy_from_user(&get, user, sizeof(get)))
+				return -EFAULT;
+			if (*len != (sizeof(get) +
+				     sizeof(struct tcp_vs_rule_u) *
+				     get.num_rules)) {
+				TCP_VS_ERR("length: %u != %u\n", *len,
+					   sizeof(get) +
+					   sizeof(struct tcp_vs_rule_u) *
+					   get.num_rules);
+				return -EINVAL;
+			}
+			ret = __tcp_vs_get_rule_entries(&get, user);
 		}
-		if (copy_from_user(&get, user, sizeof(get)))
-			return -EFAULT;
-		if (*len != (sizeof(get) +
-			     sizeof(struct tcp_vs_rule_u)*get.num_rules)) {
-			TCP_VS_ERR("length: %u != %u\n", *len,
-				   sizeof(get)+sizeof(struct tcp_vs_rule_u)*get.num_rules);
-			return -EINVAL;
-		}
-		ret = __tcp_vs_get_rule_entries(&get, user);
-	}
-	break;
+		break;
 
 	default:
 		ret = -EINVAL;
@@ -1010,9 +1036,9 @@ do_tcp_vs_get_ctl(struct sock *sk, int cmd, void *user, int *len)
 
 
 static struct nf_sockopt_ops tcp_vs_sockopts = {
-	{ NULL, NULL }, PF_INET,
-	TCP_VS_BASE_CTL, TCP_VS_SO_SET_MAX+1, do_tcp_vs_set_ctl,
-	TCP_VS_BASE_CTL, TCP_VS_SO_GET_MAX+1, do_tcp_vs_get_ctl
+	{NULL, NULL}, PF_INET,
+	TCP_VS_BASE_CTL, TCP_VS_SO_SET_MAX + 1, do_tcp_vs_set_ctl,
+	TCP_VS_BASE_CTL, TCP_VS_SO_GET_MAX + 1, do_tcp_vs_get_ctl
 };
 
 
@@ -1047,7 +1073,8 @@ static ctl_table ktcpvs_root_table[] = {
 };
 
 
-int tcp_vs_control_start(void)
+int
+tcp_vs_control_start(void)
 {
 	int ret;
 
@@ -1064,7 +1091,8 @@ int tcp_vs_control_start(void)
 }
 
 
-void tcp_vs_control_stop(void)
+void
+tcp_vs_control_stop(void)
 {
 	unregister_sysctl_table(ktcpvs_table_header);
 	nf_unregister_sockopt(&tcp_vs_sockopts);
