@@ -1,7 +1,7 @@
 /*
  * libtcpvs:	Library for manipulating TCPVS through [gs]etsockopt
  *
- * Version:     $Id: libtcpvs.c,v 1.3 2003/02/27 02:54:40 wensong Exp $
+ * Version:     $Id: libtcpvs.c,v 1.4 2003/05/23 02:08:34 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -27,7 +27,8 @@ static int tcpvs_cmd = 0;
 struct tcp_vs_getinfo tcpvs_info;
 
 
-int tcpvs_init(void)
+int
+tcpvs_init(void)
 {
 	socklen_t len;
 
@@ -36,14 +37,15 @@ int tcpvs_init(void)
 		return -1;
 
 	if (getsockopt(sockfd, IPPROTO_IP, TCP_VS_SO_GET_INFO,
-		       (char *)&tcpvs_info, &len))
+		       (char *) &tcpvs_info, &len))
 		return -1;
 
 	return 0;
 }
 
 
-unsigned int tcpvs_version(void)
+unsigned int
+tcpvs_version(void)
 {
 	return tcpvs_info.version;
 }
@@ -53,16 +55,17 @@ static inline void *
 memdup2(const void *src1, size_t n1, const void *src2, size_t n2)
 {
 	void *dest;
-	if (!(dest = malloc(n1+n2)))
+	if (!(dest = malloc(n1 + n2)))
 		return NULL;
 
 	memcpy(dest, src1, n1);
-	memcpy(dest+n1, src2, n2);
+	memcpy(dest + n1, src2, n2);
 	return dest;
 }
 
 
-int tcpvs_add_service(struct tcp_vs_ident *id, struct tcp_vs_config *conf)
+int
+tcpvs_add_service(struct tcp_vs_ident *id, struct tcp_vs_config *conf)
 {
 	void *arg;
 	int result;
@@ -72,12 +75,13 @@ int tcpvs_add_service(struct tcp_vs_ident *id, struct tcp_vs_config *conf)
 
 	tcpvs_cmd = TCP_VS_SO_SET_ADD;
 	result = setsockopt(sockfd, IPPROTO_IP, TCP_VS_SO_SET_ADD,
-			    arg, sizeof(*id)+sizeof(*conf));
+			    arg, sizeof(*id) + sizeof(*conf));
 	free(arg);
 	return result;
 }
 
-int tcpvs_edit_service(struct tcp_vs_ident *id, struct tcp_vs_config *conf)
+int
+tcpvs_edit_service(struct tcp_vs_ident *id, struct tcp_vs_config *conf)
 {
 	void *arg;
 	int result;
@@ -86,44 +90,49 @@ int tcpvs_edit_service(struct tcp_vs_ident *id, struct tcp_vs_config *conf)
 		return ENOMEM;
 
 	result = setsockopt(sockfd, IPPROTO_IP, TCP_VS_SO_SET_EDIT,
-			    arg, sizeof(*id)+sizeof(*conf));
+			    arg, sizeof(*id) + sizeof(*conf));
 	free(arg);
 	return result;
 }
 
 
-int tcpvs_del_service(struct tcp_vs_ident *id)
+int
+tcpvs_del_service(struct tcp_vs_ident *id)
 {
 	tcpvs_cmd = TCP_VS_SO_SET_DEL;
 	return setsockopt(sockfd, IPPROTO_IP,
-			  TCP_VS_SO_SET_DEL, (void*)id, sizeof(*id));
+			  TCP_VS_SO_SET_DEL, (void *) id, sizeof(*id));
 }
 
 
-int tcpvs_start_service(struct tcp_vs_ident *id)
+int
+tcpvs_start_service(struct tcp_vs_ident *id)
 {
 	tcpvs_cmd = TCP_VS_SO_SET_START;
 	return setsockopt(sockfd, IPPROTO_IP,
-			  TCP_VS_SO_SET_START, (void*)id, sizeof(*id));
+			  TCP_VS_SO_SET_START, (void *) id, sizeof(*id));
 }
 
 
-int tcpvs_stop_service(struct tcp_vs_ident *id)
+int
+tcpvs_stop_service(struct tcp_vs_ident *id)
 {
 	tcpvs_cmd = TCP_VS_SO_SET_STOP;
 	return setsockopt(sockfd, IPPROTO_IP,
-			  TCP_VS_SO_SET_STOP, (void*)id, sizeof(*id));
+			  TCP_VS_SO_SET_STOP, (void *) id, sizeof(*id));
 }
 
 
-int tcpvs_flush(void)
+int
+tcpvs_flush(void)
 {
 	tcpvs_cmd = TCP_VS_SO_SET_FLUSH;
 	return setsockopt(sockfd, IPPROTO_IP,
 			  TCP_VS_SO_SET_FLUSH, NULL, 0);
 }
 
-int tcpvs_add_dest(struct tcp_vs_ident *id, struct tcp_vs_dest_u *dest)
+int
+tcpvs_add_dest(struct tcp_vs_ident *id, struct tcp_vs_dest_u *dest)
 {
 	void *arg;
 	int result;
@@ -133,12 +142,13 @@ int tcpvs_add_dest(struct tcp_vs_ident *id, struct tcp_vs_dest_u *dest)
 
 	tcpvs_cmd = TCP_VS_SO_SET_ADDDEST;
 	result = setsockopt(sockfd, IPPROTO_IP, TCP_VS_SO_SET_ADDDEST,
-			    arg, sizeof(*id)+sizeof(*dest));
+			    arg, sizeof(*id) + sizeof(*dest));
 	free(arg);
 	return result;
 }
 
-int tcpvs_edit_dest(struct tcp_vs_ident *id, struct tcp_vs_dest_u *dest)
+int
+tcpvs_edit_dest(struct tcp_vs_ident *id, struct tcp_vs_dest_u *dest)
 {
 	void *arg;
 	int result;
@@ -148,12 +158,13 @@ int tcpvs_edit_dest(struct tcp_vs_ident *id, struct tcp_vs_dest_u *dest)
 
 	tcpvs_cmd = TCP_VS_SO_SET_EDITDEST;
 	result = setsockopt(sockfd, IPPROTO_IP, TCP_VS_SO_SET_EDITDEST,
-			    arg, sizeof(*id)+sizeof(*dest));
+			    arg, sizeof(*id) + sizeof(*dest));
 	free(arg);
 	return result;
 }
 
-int tcpvs_del_dest(struct tcp_vs_ident *id, struct tcp_vs_dest_u *dest)
+int
+tcpvs_del_dest(struct tcp_vs_ident *id, struct tcp_vs_dest_u *dest)
 {
 	void *arg;
 	int result;
@@ -163,13 +174,14 @@ int tcpvs_del_dest(struct tcp_vs_ident *id, struct tcp_vs_dest_u *dest)
 
 	tcpvs_cmd = TCP_VS_SO_SET_DELDEST;
 	result = setsockopt(sockfd, IPPROTO_IP, TCP_VS_SO_SET_DELDEST,
-			    arg, sizeof(*id)+sizeof(*dest));
+			    arg, sizeof(*id) + sizeof(*dest));
 	free(arg);
 	return result;
 }
 
 
-int tcpvs_add_rule(struct tcp_vs_ident *id, struct tcp_vs_rule_u *rule)
+int
+tcpvs_add_rule(struct tcp_vs_ident *id, struct tcp_vs_rule_u *rule)
 {
 	void *arg;
 	int result;
@@ -179,13 +191,14 @@ int tcpvs_add_rule(struct tcp_vs_ident *id, struct tcp_vs_rule_u *rule)
 
 	tcpvs_cmd = TCP_VS_SO_SET_ADDRULE;
 	result = setsockopt(sockfd, IPPROTO_IP, TCP_VS_SO_SET_ADDRULE,
-			    arg, sizeof(*id)+sizeof(*rule));
+			    arg, sizeof(*id) + sizeof(*rule));
 	free(arg);
 	return result;
 }
 
 
-int tcpvs_del_rule(struct tcp_vs_ident *id, struct tcp_vs_rule_u *rule)
+int
+tcpvs_del_rule(struct tcp_vs_ident *id, struct tcp_vs_rule_u *rule)
 {
 	void *arg;
 	int result;
@@ -195,13 +208,14 @@ int tcpvs_del_rule(struct tcp_vs_ident *id, struct tcp_vs_rule_u *rule)
 
 	tcpvs_cmd = TCP_VS_SO_SET_DELRULE;
 	result = setsockopt(sockfd, IPPROTO_IP, TCP_VS_SO_SET_DELRULE,
-			    arg, sizeof(*id)+sizeof(*rule));
+			    arg, sizeof(*id) + sizeof(*rule));
 	free(arg);
 	return result;
 }
 
 
-struct tcp_vs_service_u *tcpvs_get_service(struct tcp_vs_ident *id)
+struct tcp_vs_service_u *
+tcpvs_get_service(struct tcp_vs_ident *id)
 {
 	struct tcp_vs_service_u *svc;
 	socklen_t len;
@@ -212,7 +226,7 @@ struct tcp_vs_service_u *tcpvs_get_service(struct tcp_vs_ident *id)
 
 	strcpy(svc->ident.name, id->name);
 	if (getsockopt(sockfd, IPPROTO_IP, TCP_VS_SO_GET_SERVICE,
-		       (char *)svc, &len)) {
+		       (char *) svc, &len)) {
 		free(svc);
 		return NULL;
 	}
@@ -220,13 +234,14 @@ struct tcp_vs_service_u *tcpvs_get_service(struct tcp_vs_ident *id)
 }
 
 
-struct tcp_vs_get_services *tcpvs_get_services(void)
+struct tcp_vs_get_services *
+tcpvs_get_services(void)
 {
 	struct tcp_vs_get_services *get;
 	socklen_t len;
 
 	len = sizeof(*get) +
-		sizeof(struct tcp_vs_service_u)*tcpvs_info.num_services;
+	    sizeof(struct tcp_vs_service_u) * tcpvs_info.num_services;
 	if (!(get = malloc(len)))
 		return NULL;
 
@@ -240,12 +255,13 @@ struct tcp_vs_get_services *tcpvs_get_services(void)
 }
 
 
-struct tcp_vs_get_dests *tcpvs_get_dests(struct tcp_vs_service_u *svc)
+struct tcp_vs_get_dests *
+tcpvs_get_dests(struct tcp_vs_service_u *svc)
 {
 	struct tcp_vs_get_dests *d;
 	socklen_t len;
 
-	len = sizeof(*d) + sizeof(struct tcp_vs_dest_u)*svc->num_dests;
+	len = sizeof(*d) + sizeof(struct tcp_vs_dest_u) * svc->num_dests;
 	if (!(d = malloc(len)))
 		return NULL;
 
@@ -261,12 +277,13 @@ struct tcp_vs_get_dests *tcpvs_get_dests(struct tcp_vs_service_u *svc)
 }
 
 
-struct tcp_vs_get_rules *tcpvs_get_rules(struct tcp_vs_service_u *svc)
+struct tcp_vs_get_rules *
+tcpvs_get_rules(struct tcp_vs_service_u *svc)
 {
 	struct tcp_vs_get_rules *r;
 	socklen_t len;
 
-	len = sizeof(*r) + sizeof(struct tcp_vs_rule_u)*svc->num_rules;
+	len = sizeof(*r) + sizeof(struct tcp_vs_rule_u) * svc->num_rules;
 	if (!(r = malloc(len)))
 		return NULL;
 
@@ -282,39 +299,40 @@ struct tcp_vs_get_rules *tcpvs_get_rules(struct tcp_vs_service_u *svc)
 }
 
 
-void tcpvs_close(void)
+void
+tcpvs_close(void)
 {
 	close(sockfd);
 }
 
 
-const char *tcpvs_strerror(int err)
+const char *
+tcpvs_strerror(int err)
 {
 	unsigned int i;
 	struct table_struct {
 		int cmd;
 		int err;
 		const char *message;
-	} table [] =
-	  { { 0, EPERM, "Permission denied (you must be root)" },
-	    { 0, EINVAL, "Module is wrong version" },
-	    { 0, ENOPROTOOPT, "The ktcpvs module not loaded" },
-	    { 0, ENOMEM, "Memory allocation problem" },
-	    { TCP_VS_SO_SET_ADD, EEXIST, "Service already exists" },
-	    { TCP_VS_SO_SET_ADD, ENOENT, "Scheduler not found" },
-	    { TCP_VS_SO_SET_EDIT, ESRCH, "No such service" },
-	    { TCP_VS_SO_SET_EDIT, ENOENT, "Scheduler not found" },
-	    { TCP_VS_SO_SET_DEL, ESRCH, "No such service" },
-	    { TCP_VS_SO_SET_ADDDEST, ESRCH, "Service not defined" },
-	    { TCP_VS_SO_SET_ADDDEST, EEXIST, "Destination already exists" },
-	    { TCP_VS_SO_SET_EDITDEST, ESRCH, "Service not defined" },
-	    { TCP_VS_SO_SET_EDITDEST, ENOENT, "No such destination" },
-	    { TCP_VS_SO_SET_DELDEST, ESRCH, "Service not defined" },
-	    { TCP_VS_SO_SET_DELDEST, ENOENT, "No such destination" },
-	    { TCP_VS_SO_SET_DELDEST, EBUSY, "Destination is busy" },
-	  };
+	} table[] = { {
+	0, EPERM, "Permission denied (you must be root)"}, {
+	0, EINVAL, "Module is wrong version"}, {
+	0, ENOPROTOOPT, "The ktcpvs module not loaded"}, {
+	0, ENOMEM, "Memory allocation problem"}, {
+	TCP_VS_SO_SET_ADD, EEXIST, "Service already exists"}, {
+	TCP_VS_SO_SET_ADD, ENOENT, "Scheduler not found"}, {
+	TCP_VS_SO_SET_EDIT, ESRCH, "No such service"}, {
+	TCP_VS_SO_SET_EDIT, ENOENT, "Scheduler not found"}, {
+	TCP_VS_SO_SET_DEL, ESRCH, "No such service"}, {
+	TCP_VS_SO_SET_ADDDEST, ESRCH, "Service not defined"}, {
+	TCP_VS_SO_SET_ADDDEST, EEXIST, "Destination already exists"}, {
+	TCP_VS_SO_SET_EDITDEST, ESRCH, "Service not defined"}, {
+	TCP_VS_SO_SET_EDITDEST, ENOENT, "No such destination"}, {
+	TCP_VS_SO_SET_DELDEST, ESRCH, "Service not defined"}, {
+	TCP_VS_SO_SET_DELDEST, ENOENT, "No such destination"}, {
+	TCP_VS_SO_SET_DELDEST, EBUSY, "Destination is busy"},};
 
-	for (i = 0; i < sizeof(table)/sizeof(struct table_struct); i++) {
+	for (i = 0; i < sizeof(table) / sizeof(struct table_struct); i++) {
 		if ((!table[i].cmd || table[i].cmd == tcpvs_cmd)
 		    && table[i].err == err)
 			return table[i].message;
